==> Celeratas-1.1.1.tar.gz: Celeratas-1.1.1/Celeratas/parser/nodes.py <==
class NumberNode:
    def __init__(self, tok):
        self.tok = tok

        self.pos_start = self.tok.pos_start
        self.pos_end = self.tok.pos_end

    def __repr__(self):
        return f'{self.tok}'


class NumeralNode:
    def __init__(self, tok):
        self.tok = tok

        self.pos_start = self.tok.pos_start
        self.pos_end = self.tok.pos_end

    def __repr__(self):
        return self.tok.value


class StringNode:
    def __init__(self, str_components, pos_start, pos_end):
        self.str_components = str_components

        self.pos_start = pos_start
        self.pos_end = pos_end

    def __repr__(self):
        return f'{self.str_components}'


class BoolNode:
    def __init__(self, tok):
        self.tok = tok

        self.pos_start = self.tok.pos_start
        self.pos_end = self.tok.pos_end

    def __repr__(self):
        return self.tok.value


class ListNode:
    def __init__(self, element_nodes, pos_start, pos_end):
        self.element_nodes = element_nodes

        self.pos_start = pos_start
        self.pos_end = pos_end


class DictNode:
    def __init__(self, key_pairs, pos_start, pos_end):
        self.key_pairs = key_pairs

        self.pos_start = pos_start
        self.pos_end = pos_end


class VarAccessNode:
    def __init__(self, var_name_tok, idxes_to_get, attr_to_get):
        self.var_name_tok = var_name_tok
        self.idxes_to_get = idxes_to_get
        self.attr_to_get = attr_to_get

        self.pos_start = self.var_name_tok.pos_start
        self.pos_end = self.var_name_tok.pos_end


class VarAssignNode:
    def __init__(self, var_names_to_set, values_to_set, idxes_to_change, assign_type, pos_start, pos_end):
        self.var_names_to_set = var_names_to_set
        self.values_to_set = values_to_set
        self.idxes_to_change = idxes_to_change
        self.assign_type = assign_type

        self.pos_start = pos_start
        self.pos_end = pos_end


class BinOpNode:
    def __init__(self, left_node, op_tok, right_node):
        self.left_node = left_node
        self.op_tok = op_tok
        self.right_node = right_node

        self.pos_start = self.left_node.pos_start
        self.pos_end = self.right_node.pos_end

    def __repr__(self):
        return f'({self.left_node}, {self.op_tok}, {self.right_node})'


class UnaryOpNode:
    def __init__(self, op_tok, node):
        self.op_tok = op_tok
        self.node = node

        self.pos_start = self.op_tok.pos_start
        self.pos_end = node.pos_end

    def __repr__(self):
        return f'({self.op_tok}, {self.node})'


class IfNode:
    def __init__(self, cases, else_case):
        self.cases = cases
        self.else_case = else_case

        self.pos_start = self.cases[0][0].pos_start
        self.pos_end = (
            self.else_case or self.cases[len(self.cases) - 1])[0].pos_end


class TryNode:
    def __init__(self, try_body, except_body, except_name, except_as):
        self.try_body = try_body
        self.except_body = except_body
        self.except_name = except_name
        self.except_as = except_as

        self.pos_start = self.try_body.pos_start
        self.pos_end = self.except_body.pos_end if self.except_body else self.try_body.pos_end


class ForNode:
    def __init__(self, var_name_tok, start_value_node, end_value_node, step_value_node, body_node, should_return_null):
        self.var_name_tok = var_name_tok
        self.start_value_node = start_value_node
        self.end_value_node = end_value_node
        self.step_value_node = step_value_node
        self.body_node = body_node
        self.should_return_null = should_return_null

        self.pos_start = self.var_name_tok.pos_start
        self.pos_end = self.body_node.pos_end


class WhileNode:
    def __init__(self, condition_node, body_node, should_return_null):
        self.condition_node = condition_node
        self.body_node = body_node
        self.should_return_null = should_return_null

        self.pos_start = self.condition_node.pos_start
        self.pos_end = self.body_node.pos_end


class FuncDefNode:
    def __init__(self, var_name_tok, arg_name_toks, body_node, should_auto_return):
        self.var_name_tok = var_name_tok
        self.arg_name_toks = arg_name_toks
        self.body_node = body_node
        self.should_auto_return = should_auto_return

        if self.var_name_tok:
            self.pos_start = self.var_name_tok.pos_start
        elif len(self.arg_name_toks) > 0:
            self.pos_start = self.arg_name_toks[0].pos_start
        else:
            self.pos_start = self.body_node.pos_start

        self.pos_end = self.body_node.pos_end


class CallNode:
    def __init__(self, node_to_call, arg_nodes):
        self.node_to_call = node_to_call
        self.arg_nodes = arg_nodes

        self.pos_start = self.node_to_call.pos_start

        if len(self.arg_nodes) > 0:
            self.pos_end = self.arg_nodes[len(self.arg_nodes) - 1].pos_end
        else:
            self.pos_end = self.node_to_call.pos_end


class ReturnNode:
    def __init__(self, node_to_return, pos_start, pos_end):
        self.node_to_return = node_to_return

        self.pos_start = pos_start
        self.pos_end = pos_end


class ContinueNode:
    def __init__(self, pos_start, pos_end):
        self.pos_start = pos_start
        self.pos_end = pos_end


class BreakNode:
    def __init__(self, pos_start, pos_end):
        self.pos_start = pos_start
        self.pos_end = pos_end

==> Celeratas-1.2.1.tar.gz: Celeratas-1.2.1/Celeratas/parser/nodes.py <==
class NumberNode:
    def __init__(self, value, pos_start, pos_end):
        self.value = value

        self.pos_start = pos_start
        self.pos_end = pos_end

    def __repr__(self):
        return f'{self.value}'


class NumeralNode:
    def __init__(self, value, pos_start, pos_end):
        self.value = value

        self.pos_start = pos_start
        self.pos_end = pos_end

    def __repr__(self):
        return self.value


class StringNode:
    def __init__(self, str_components, pos_start, pos_end):
        self.str_components = str_components

        self.pos_start = pos_start
        self.pos_end = pos_end

    def __repr__(self):
        return f'{self.str_components}'


class BoolNode:
    def __init__(self, value, pos_start, pos_end):
        self.value = value

        self.pos_start = pos_start
        self.pos_end = pos_end

    def __repr__(self):
        return self.value


class ListNode:
    def __init__(self, element_nodes, pos_start, pos_end):
        self.element_nodes = element_nodes

        self.pos_start = pos_start
        self.pos_end = pos_end


class DictNode:
    def __init__(self, key_pairs, pos_start, pos_end):
        self.key_pairs = key_pairs

        self.pos_start = pos_start
        self.pos_end = pos_end


class VarAccessNode:
    def __init__(self, var_name_to_get, idxes_to_get, attrs_to_get, pos_start, pos_end):
        self.var_name_to_get = var_name_to_get
        self.idxes_to_get = idxes_to_get
        self.attrs_to_get = attrs_to_get

        self.pos_start = pos_start
        self.pos_end = pos_end


class VarAssignNode:
    def __init__(self, vars_to_set, values_to_set, assign_type, pos_start, pos_end):
        self.vars_to_set = vars_to_set
        self.values_to_set = values_to_set
        self.assign_type = assign_type

        self.pos_start = pos_start
        self.pos_end = pos_end


class BinOpNode:
    def __init__(self, left_node, op_tok, right_node, pos_start, pos_end):
        self.left_node = left_node
        self.op_tok = op_tok
        self.right_node = right_node

        self.pos_start = pos_start
        self.pos_end = pos_end

    def __repr__(self):
        return f'({self.left_node}, {self.op_tok}, {self.right_node})'


class UnaryOpNode:
    def __init__(self, op_tok, node, pos_start, pos_end):
        self.op_tok = op_tok
        self.node = node

        self.pos_start = pos_start
        self.pos_end = pos_end

    def __repr__(self):
        return f'({self.op_tok}, {self.node})'


class IfNode:
    def __init__(self, cases, else_case, pos_start, pos_end):
        self.cases = cases
        self.else_case = else_case

        self.pos_start = pos_start
        self.pos_end = pos_end


class TryNode:
    def __init__(self, try_body, except_body, except_name, except_as, should_return_null, pos_start, pos_end):
        self.try_body = try_body
        self.except_body = except_body
        self.except_name = except_name
        self.except_as = except_as
        self.should_return_null = should_return_null

        self.pos_start = pos_start
        self.pos_end = pos_end


class ForNode:
    def __init__(self, var_name, start_value_node, end_value_node, step_value_node, body_node, should_return_null, pos_start, pos_end):
        self.var_name = var_name
        self.start_value_node = start_value_node
        self.end_value_node = end_value_node
        self.step_value_node = step_value_node
        self.body_node = body_node
        self.should_return_null = should_return_null

        self.pos_start = pos_start
        self.pos_end = pos_end


class WhileNode:
    def __init__(self, condition_node, body_node, should_return_null, pos_start, pos_end):
        self.condition_node = condition_node
        self.body_node = body_node
        self.should_return_null = should_return_null

        self.pos_start = pos_start
        self.pos_end = pos_end


class FuncDefNode:
    def __init__(self, func_name, args, body_node, should_auto_return, pos_start, pos_end):
        self.func_name = func_name
        self.args = args
        self.body_node = body_node
        self.should_auto_return = should_auto_return

        self.pos_start = pos_start
        self.pos_end = pos_end


class CallNode:
    def __init__(self, node_to_call, arg_nodes, pos_start, pos_end):
        self.node_to_call = node_to_call
        self.arg_nodes = arg_nodes

        self.pos_start = pos_start
        self.pos_end = pos_end


class ReturnNode:
    def __init__(self, node_to_return, pos_start, pos_end):
        self.node_to_return = node_to_return

        self.pos_start = pos_start
        self.pos_end = pos_end


class ContinueNode:
    def __init__(self, pos_start, pos_end):
        self.pos_start = pos_start
        self.pos_end = pos_end


class BreakNode:
    def __init__(self, pos_start, pos_end):
        self.pos_start = pos_start
        self.pos_end = pos_end
